@@ -7,18 +7,8 @@ Interchange6::Schema::Result::Address
 
 =cut
 
-use strict;
-use warnings;
-
-use base 'DBIx::Class::Core';
-
-__PACKAGE__->load_components(qw(InflateColumn::DateTime TimeStamp));
-
-=head1 TABLE: C<addresses>
-
-=cut
-
-__PACKAGE__->table("addresses");
+use Interchange6::Schema::Candy -components =>
+  [qw(InflateColumn::DateTime TimeStamp)];
 
 =head1 ACCESSORS
 
@@ -28,6 +18,16 @@ __PACKAGE__->table("addresses");
   is_auto_increment: 1
   is_nullable: 0
   sequence: 'addresses_addresses_id_seq'
+  primary key
+
+=cut
+
+primary_column addresses_id => {
+    data_type         => "integer",
+    is_auto_increment => 1,
+    is_nullable       => 0,
+    sequence          => "addresses_addresses_id_seq",
+};
 
 =head2 users_id
 
@@ -35,6 +35,14 @@ __PACKAGE__->table("addresses");
   is_foreign_key: 1
   is_nullable: 0
 
+=cut
+
+column users_id => {
+    data_type      => "integer",
+    is_foreign_key => 1,
+    is_nullable    => 0,
+};
+
 =head2 type
 
   data_type: 'varchar'
@@ -42,12 +50,29 @@ __PACKAGE__->table("addresses");
   is_nullable: 0
   size: 16
 
+=cut
+
+column type => {
+    data_type     => "varchar",
+    default_value => "",
+    is_nullable   => 0,
+    size          => 16,
+};
+
 =head2 archived
 
   data_type: 'boolean'
   default_value: 0
   is_nullable: 0
 
+=cut
+
+column archived => {
+    data_type     => "boolean",
+    default_value => 0,
+    is_nullable   => 0,
+};
+
 =head2 first_name
 
   data_type: 'varchar'
@@ -55,6 +80,15 @@ __PACKAGE__->table("addresses");
   is_nullable: 0
   size: 255
 
+=cut
+
+column first_name => {
+    data_type     => "varchar",
+    default_value => "",
+    is_nullable   => 0,
+    size          => 255,
+};
+
 =head2 last_name
 
   data_type: 'varchar'
@@ -62,13 +96,32 @@ __PACKAGE__->table("addresses");
   is_nullable: 0
   size: 255
 
+=cut
+
+column last_name => {
+    data_type     => "varchar",
+    default_value => "",
+    is_nullable   => 0,
+    size          => 255,
+};
+
 =head2 company
 
+
   data_type: 'varchar'
   default_value: (empty string)
   is_nullable: 0
   size: 255
 
+=cut
+
+column company => {
+    data_type     => "varchar",
+    default_value => "",
+    is_nullable   => 0,
+    size          => 255,
+};
+
 =head2 address
 
   data_type: 'varchar'
@@ -76,6 +129,15 @@ __PACKAGE__->table("addresses");
   is_nullable: 0
   size: 255
 
+=cut
+
+column address => {
+    data_type     => "varchar",
+    default_value => "",
+    is_nullable   => 0,
+    size          => 255,
+};
+
 =head2 address_2
 
   data_type: 'varchar'
@@ -83,6 +145,15 @@ __PACKAGE__->table("addresses");
   is_nullable: 0
   size: 255
 
+=cut
+
+column address_2 => {
+    data_type     => "varchar",
+    default_value => "",
+    is_nullable   => 0,
+    size          => 255,
+};
+
 =head2 postal_code
 
   data_type: 'varchar'
@@ -90,6 +161,15 @@ __PACKAGE__->table("addresses");
   is_nullable: 0
   size: 255
 
+=cut
+
+column postal_code => {
+    data_type     => "varchar",
+    default_value => "",
+    is_nullable   => 0,
+    size          => 255,
+};
+
 =head2 city
 
   data_type: 'varchar'
@@ -97,6 +177,15 @@ __PACKAGE__->table("addresses");
   is_nullable: 0
   size: 255
 
+=cut
+
+column city => {
+    data_type     => "varchar",
+    default_value => "",
+    is_nullable   => 0,
+    size          => 255,
+};
+
 =head2 phone
 
   data_type: 'varchar'
@@ -104,12 +193,29 @@ __PACKAGE__->table("addresses");
   is_nullable: 0
   size: 32
 
+=cut
+
+column phone => {
+    data_type     => "varchar",
+    default_value => "",
+    is_nullable   => 0,
+    size          => 32,
+};
+
 =head2 states_id
 
   data_type: 'integer'
   is_foreign_key: 1
   is_nullable: 1
 
+=cut
+
+column states_id => {
+    data_type      => "integer",
+    is_foreign_key => 1,
+    is_nullable    => 1,
+};
+
 =head2 country_iso_code
 
   data_type: 'char'
@@ -117,12 +223,29 @@ __PACKAGE__->table("addresses");
   is_nullable: 0
   size: 2
 
+=cut
+
+column country_iso_code => {
+    data_type      => "char",
+    is_foreign_key => 1,
+    is_nullable    => 0,
+    size           => 2,
+};
+
 =head2 created
 
   data_type: 'datetime'
   set_on_create: 1
   is_nullable: 0
 
+=cut
+
+column created => {
+    data_type     => "datetime",
+    set_on_create => 1,
+    is_nullable   => 0,
+};
+
 =head2 last_modified
 
   data_type: 'datetime'
@@ -132,57 +255,12 @@ __PACKAGE__->table("addresses");
 
 =cut
 
-__PACKAGE__->add_columns(
-  "addresses_id",
-  {
-    data_type         => "integer",
-    is_auto_increment => 1,
-    is_nullable       => 0,
-    sequence          => "addresses_addresses_id_seq",
-  },
-  "users_id",
-  { data_type => "integer", is_foreign_key => 1, is_nullable => 0 },
-  "type",
-  { data_type => "varchar", default_value => "", is_nullable => 0, size => 16 },
-  "archived",
-  { data_type => "boolean", default_value => 0, is_nullable => 0 },
-  "first_name",
-  { data_type => "varchar", default_value => "", is_nullable => 0, size => 255 },
-  "last_name",
-  { data_type => "varchar", default_value => "", is_nullable => 0, size => 255 },
-  "company",
-  { data_type => "varchar", default_value => "", is_nullable => 0, size => 255 },
-  "address",
-  { data_type => "varchar", default_value => "", is_nullable => 0, size => 255 },
-  "address_2",
-  { data_type => "varchar", default_value => "", is_nullable => 0, size => 255 },
-  "postal_code",
-  { data_type => "varchar", default_value => "", is_nullable => 0, size => 255 },
-  "city",
-  { data_type => "varchar", default_value => "", is_nullable => 0, size => 255 },
-  "phone",
-  { data_type => "varchar", default_value => "", is_nullable => 0, size => 32 },
-  "states_id",
-  { data_type => "integer", is_foreign_key => 1, is_nullable => 1 },
-  "country_iso_code",
-  { data_type => "char", is_foreign_key => 1, is_nullable => 0, size => 2 },
-  "created",
-  { data_type => "datetime", set_on_create => 1, is_nullable => 0 },
-  "last_modified",
-  { data_type => "datetime", set_on_create => 1, set_on_update => 1, is_nullable => 0 },
-);
-
-=head1 PRIMARY KEY
-
-=over 4
-
-=item * L</addresses_id>
-
-=back
-
-=cut
-
-__PACKAGE__->set_primary_key("addresses_id");
+column last_modified => {
+    data_type     => "datetime",
+    set_on_create => 1,
+    set_on_update => 1,
+    is_nullable   => 0,
+};
 
 =head1 RELATIONS
 
@@ -194,12 +272,10 @@ Related object: L<Interchange6::Schema::Result::OrderlinesShipping>
 
 =cut
 
-__PACKAGE__->has_many(
-  "orderlines_shipping",
-  "Interchange6::Schema::Result::OrderlinesShipping",
+has_many
+  orderlines_shipping => "Interchange6::Schema::Result::OrderlinesShipping",
   { "foreign.addresses_id" => "self.addresses_id" },
-  { cascade_copy => 0, cascade_delete => 0 },
-);
+  { cascade_copy           => 0, cascade_delete => 0 };
 
 =head2 orders
 
@@ -209,12 +285,10 @@ Related object: L<Interchange6::Schema::Result::Order>
 
 =cut
 
-__PACKAGE__->has_many(
-  "orders",
-  "Interchange6::Schema::Result::Order",
+has_many
+  orders => "Interchange6::Schema::Result::Order",
   { "foreign.billing_addresses_id" => "self.addresses_id" },
-  { cascade_copy => 0, cascade_delete => 0 },
-);
+  { cascade_copy                   => 0, cascade_delete => 0 };
 
 =head2 user
 
@@ -224,12 +298,10 @@ Related object: L<Interchange6::Schema::Result::User>
 
 =cut
 
-__PACKAGE__->belongs_to(
-  "user",
-  "Interchange6::Schema::Result::User",
-  { users_id => "users_id" },
-  { is_deferrable => 1, on_delete => "CASCADE", on_update => "CASCADE" },
-);
+belongs_to
+  user => "Interchange6::Schema::Result::User",
+  { users_id      => "users_id" },
+  { is_deferrable => 1, on_delete => "CASCADE", on_update => "CASCADE" };
 
 =head2 state
 
@@ -239,12 +311,10 @@ Related object: L<Interchange6::Schema::Result::State>
 
 =cut
 
-__PACKAGE__->belongs_to(
-  "state",
-  "Interchange6::Schema::Result::State",
-  { states_id => "states_id" },
-  { is_deferrable => 1, on_delete => "CASCADE", on_update => "CASCADE" },
-);
+belongs_to
+  state => "Interchange6::Schema::Result::State",
+  { states_id     => "states_id" },
+  { is_deferrable => 1, on_delete => "CASCADE", on_update => "CASCADE" };
 
 =head2 country
 
@@ -254,12 +324,10 @@ Related object: L<Interchange6::Schema::Result::Country>
 
 =cut
 
-__PACKAGE__->belongs_to(
-  "country",
-  "Interchange6::Schema::Result::Country",
-  { country_iso_code => "country_iso_code" },
-  { is_deferrable => 1, on_delete => "CASCADE", on_update => "CASCADE" },
-);
+belongs_to
+  country => "Interchange6::Schema::Result::Country",
+  "country_iso_code",
+  { is_deferrable => 1, on_delete => "CASCADE", on_update => "CASCADE" };
 
 =head2 orderlines
 
@@ -269,6 +337,6 @@ Composing rels: L</orderlines_shipping> -> orderline
 
 =cut
 
-__PACKAGE__->many_to_many("orderlines", "orderlines_shipping", "orderline");
+many_to_many orderlines => "orderlines_shipping", "orderline";
 
 1;
