@@ -1,4 +1,5 @@
 use utf8;
+
 package Interchange6::Schema::Result::Media;
 
 =head1 NAME
@@ -7,18 +8,8 @@ Interchange6::Schema::Result::Media
 
 =cut
 
-use strict;
-use warnings;
-
-use base 'DBIx::Class::Core';
-
-__PACKAGE__->load_components(qw(InflateColumn::DateTime TimeStamp));
-
-=head1 TABLE: C<media>
-
-=cut
-
-__PACKAGE__->table("media");
+use Interchange6::Schema::Candy -components =>
+  [qw(InflateColumn::DateTime TimeStamp)];
 
 =head1 ACCESSORS
 
@@ -28,6 +19,16 @@ __PACKAGE__->table("media");
   is_auto_increment: 1
   is_nullable: 0
   sequence: 'media_media_id_seq'
+  primary key
+
+=cut
+
+primary_column media_id => {
+    data_type         => "integer",
+    is_auto_increment => 1,
+    is_nullable       => 0,
+    sequence          => "media_media_id_seq",
+};
 
 =head2 file
 
@@ -35,6 +36,16 @@ __PACKAGE__->table("media");
   default_value: (empty string)
   is_nullable: 0
   size: 255
+  unique constraint
+
+=cut
+
+unique_column file => {
+    data_type     => "varchar",
+    default_value => "",
+    is_nullable   => 0,
+    size          => 255
+};
 
 =head2 uri
 
@@ -43,6 +54,15 @@ __PACKAGE__->table("media");
   is_nullable: 0
   size: 255
 
+=cut
+
+column uri => {
+    data_type     => "varchar",
+    default_value => "",
+    is_nullable   => 0,
+    size          => 255
+};
+
 =head2 mime_type
 
   data_type: 'varchar'
@@ -50,6 +70,15 @@ __PACKAGE__->table("media");
   is_nullable: 0
   size: 255
 
+=cut
+
+column mime_type => {
+    data_type     => "varchar",
+    default_value => "",
+    is_nullable   => 0,
+    size          => 255
+};
+
 =head2 label
 
   data_type: 'varchar'
@@ -57,18 +86,37 @@ __PACKAGE__->table("media");
   is_nullable: 0
   size: 255
 
+=cut
+
+column label => {
+    data_type     => "varchar",
+    default_value => "",
+    is_nullable   => 0,
+    size          => 255
+};
+
 =head2 author_users_id
 
   data_type: 'integer'
   is_foreign_key: 1
   is_nullable: 1
 
+=cut
+
+column author_users_id =>
+  { data_type => "integer", is_foreign_key => 1, is_nullable => 1 };
+
 =head2 created
 
   data_type: 'datetime'
   set_on_create: 1
   is_nullable: 0
 
+=cut
+
+column created =>
+  { data_type => "datetime", set_on_create => 1, is_nullable => 0 };
+
 =head2 last_modified
 
   data_type: 'datetime'
@@ -76,12 +124,26 @@ __PACKAGE__->table("media");
   set_on_update: 1
   is_nullable: 0
 
+=cut
+
+column last_modified => {
+    data_type     => "datetime",
+    set_on_create => 1,
+    set_on_update => 1,
+    is_nullable   => 0
+};
+
 =head2 active
 
   data_type: 'boolean'
   default_value: 1
   is_nullable: 0
 
+=cut
+
+column active =>
+  { data_type => "boolean", default_value => 1, is_nullable => 0 };
+
 =head2 media_types_id
 
   data_type: 'integer'
@@ -90,45 +152,8 @@ __PACKAGE__->table("media");
 
 =cut
 
-__PACKAGE__->add_columns(
-  "media_id",
-  {
-    data_type         => "integer",
-    is_auto_increment => 1,
-    is_nullable       => 0,
-    sequence          => "media_media_id_seq",
-  },
-  "file",
-  { data_type => "varchar", default_value => "", is_nullable => 0, size => 255 },
-  "uri",
-  { data_type => "varchar", default_value => "", is_nullable => 0, size => 255 },
-  "mime_type",
-  { data_type => "varchar", default_value => "", is_nullable => 0, size => 255 },
-  "label",
-  { data_type => "varchar", default_value => "", is_nullable => 0, size => 255 },
-  "author_users_id",
-  { data_type => "integer", is_foreign_key => 1, is_nullable => 1 },
-  "created",
-  { data_type => "datetime", set_on_create => 1, is_nullable => 0 },
-  "last_modified",
-  { data_type => "datetime", set_on_create => 1, set_on_update => 1, is_nullable => 0 },
-  "active",
-  { data_type => "boolean", default_value => 1, is_nullable => 0 },
-  "media_types_id",
-  { data_type => "integer", is_foreign_key => 1, is_nullable => 0 },
-);
-
-=head1 PRIMARY KEY
-
-=over 4
-
-=item * L</media_id>
-
-=back
-
-=cut
-
-__PACKAGE__->set_primary_key("media_id");
+column media_types_id =>
+  { data_type => "integer", is_foreign_key => 1, is_nullable => 0 };
 
 =head1 UNIQUE CONSTRAINTS
 
@@ -144,19 +169,8 @@ __PACKAGE__->set_primary_key("media_id");
 
 =cut
 
-__PACKAGE__->add_unique_constraint(
-  "media_id_media_types_id_unique",
-  ["media_id", "media_types_id"],
-);
-
-=head2 C<media_file_unique>
-
-File should be unique
-
-=cut
-
-__PACKAGE__->add_unique_constraint("media_file_unique", ["file"]);
-
+unique_constraint media_id_media_types_id_unique =>
+  [ "media_id", "media_types_id" ];
 
 =head1 RELATIONS
 
@@ -168,12 +182,9 @@ Related object: L<Interchange6::Schema::Result::User>
 
 =cut
 
-__PACKAGE__->belongs_to(
-  "author",
-  "Interchange6::Schema::Result::User",
-  { "foreign.users_id" => "self.author_users_id" },
-  { cascade_copy => 0, cascade_delete => 0 },
-);
+belongs_to
+  author => "Interchange6::Schema::Result::User",
+  { "foreign.users_id" => "self.author_users_id" };
 
 =head2 media_type
 
@@ -183,12 +194,10 @@ Related object: L<Interchange6::Schema::Result::MediaType>
 
 =cut
 
-__PACKAGE__->belongs_to(
-  "media_type",
-  "Interchange6::Schema::Result::MediaType",
-  { media_types_id => "media_types_id" },
-  { is_deferrable => 0, on_delete => "CASCADE", on_update => "CASCADE" },
-);
+belongs_to
+  media_type => "Interchange6::Schema::Result::MediaType",
+  "media_types_id",
+  { is_deferrable => 0, on_delete => "CASCADE", on_update => "CASCADE" };
 
 =head2 media_products
 
@@ -198,12 +207,10 @@ Related object: L<Interchange6::Schema::Result::MediaProduct>
 
 =cut
 
-__PACKAGE__->has_many(
-  "media_products",
-  "Interchange6::Schema::Result::MediaProduct",
-  { "foreign.media_id" => "self.media_id" },
-  { cascade_copy => 0, cascade_delete => 0 },
-);
+has_many
+  media_products => "Interchange6::Schema::Result::MediaProduct",
+  "media_id",
+  { cascade_copy => 0, cascade_delete => 0 };
 
 =head2 products
 
@@ -211,7 +218,7 @@ Type: many_to_many with product.
 
 =cut
 
-__PACKAGE__->many_to_many("products", "media_products", "product");
+many_to_many products => "media_products", "product";
 
 =head2 displays
 
@@ -219,7 +226,7 @@ Type: many_to_many with media_displays
 
 =cut
 
-__PACKAGE__->many_to_many("displays", "media_type", "media_displays");
+many_to_many displays => "media_type", "media_displays";
 
 =head1 METHODS
 
@@ -231,8 +238,9 @@ Return the media type looking into MediaDisplay and MediaType.
 
 sub type {
     my $self = shift;
+
     # here we return just the first result. UNCLEAR if more are
-    # needed, but has many... Either we 
+    # needed, but has many... Either we
     return $self->media_type->type;
 }
 
@@ -245,10 +253,10 @@ Return an hashref with the media display type and the final uri.
 sub display_uris {
     my $self = shift;
     my %uris;
-    foreach my $d ($self->displays) {
+    foreach my $d ( $self->displays ) {
         my $path = $d->path;
-        $path =~ s!/$!!; # remove eventual trailing slash
-        $uris{$d->type} = $path . '/' . $self->uri;
+        $path =~ s!/$!!;    # remove eventual trailing slash
+        $uris{ $d->type } = $path . '/' . $self->uri;
     }
     return \%uris;
 }
@@ -260,7 +268,7 @@ Return the uri for the display type (or undef if not found).
 =cut
 
 sub display_uri {
-    my ($self, $type) = @_;
+    my ( $self, $type ) = @_;
     return $self->display_uris->{$type};
 }
 
