@@ -1,4 +1,5 @@
 use utf8;
+
 package Interchange6::Schema::Result::Navigation;
 
 =head1 NAME
@@ -7,18 +8,10 @@ Interchange6::Schema::Result::Navigation
 
 =cut
 
-use strict;
-use warnings;
+use base 'Interchange6::Schema::Base::Attribute';
 
-use base qw(DBIx::Class::Core Interchange6::Schema::Base::Attribute);
-
-=head1 TABLE: C<navigation>
-
-=cut
-
-__PACKAGE__->load_components(qw(Tree::AdjacencyList InflateColumn::DateTime TimeStamp));
-
-__PACKAGE__->table("navigation");
+use Interchange6::Schema::Candy -components =>
+  [qw(Tree::AdjacencyList InflateColumn::DateTime TimeStamp)];
 
 =head1 DESCRIPTION
 
@@ -57,6 +50,16 @@ This ensures each record has a unique value and also allows for proper ordering.
   is_auto_increment: 1
   is_nullable: 0
   sequence: 'navigation_navigation_id_seq'
+  primary key
+
+=cut
+
+primary_column navigation_id => {
+    data_type         => "integer",
+    is_auto_increment => 1,
+    is_nullable       => 0,
+    sequence          => "navigation_navigation_id_seq",
+};
 
 =head2 uri
 
@@ -64,6 +67,16 @@ This ensures each record has a unique value and also allows for proper ordering.
   default_value: (empty string)
   is_nullable: 0
   size: 255
+  unique constraint
+
+=cut
+
+unique_column uri => {
+    data_type     => "varchar",
+    default_value => "",
+    is_nullable   => 0,
+    size          => 255
+};
 
 =head2 type
 
@@ -72,6 +85,11 @@ This ensures each record has a unique value and also allows for proper ordering.
   is_nullable: 0
   size: 32
 
+=cut
+
+column type =>
+  { data_type => "varchar", default_value => "", is_nullable => 0, size => 32 };
+
 =head2 scope
 
   data_type: 'varchar'
@@ -79,6 +97,11 @@ This ensures each record has a unique value and also allows for proper ordering.
   is_nullable: 0
   size: 32
 
+=cut
+
+column scope =>
+  { data_type => "varchar", default_value => "", is_nullable => 0, size => 32 };
+
 =head2 name
 
   data_type: 'varchar'
@@ -86,6 +109,15 @@ This ensures each record has a unique value and also allows for proper ordering.
   is_nullable: 0
   size: 255
 
+=cut
+
+column name => {
+    data_type     => "varchar",
+    default_value => "",
+    is_nullable   => 0,
+    size          => 255
+};
+
 =head2 description
 
   data_type: 'varchar'
@@ -93,35 +125,68 @@ This ensures each record has a unique value and also allows for proper ordering.
   is_nullable: 0
   size: 1024
 
+=cut
+
+column description => {
+    data_type     => "varchar",
+    default_value => "",
+    is_nullable   => 0,
+    size          => 1024
+};
+
 =head2 alias
 
   data_type: 'integer'
   default_value: 0
   is_nullable: 0
 
+=cut
+
+column alias =>
+  { data_type => "integer", default_value => 0, is_nullable => 0 };
+
 =head2 parent_id
 
   data_type: 'integer'
   is_nullable: 1
 
+=cut
+
+column parent_id => { data_type => "integer", is_nullable => 1 };
+
 =head2 priority
 
   data_type: 'integer'
   default_value: 0
   is_nullable: 0
 
+=cut
+
+column priority =>
+  { data_type => "integer", default_value => 0, is_nullable => 0 };
+
 =head2 product_count
 
   data_type: 'integer'
   default_value: 0
   is_nullable: 0
 
+=cut
+
+column product_count =>
+  { data_type => "integer", default_value => 0, is_nullable => 0 };
+
 =head2 created
 
   data_type: 'datetime'
   set_on_create: 1
   is_nullable: 0
 
+=cut
+
+column created =>
+  { data_type => "datetime", set_on_create => 1, is_nullable => 0 };
+
 =head2 last_modified
 
   data_type: 'datetime'
@@ -129,6 +194,15 @@ This ensures each record has a unique value and also allows for proper ordering.
   set_on_update: 1
   is_nullable: 0
 
+=cut
+
+column last_modified => {
+    data_type     => "datetime",
+    set_on_create => 1,
+    set_on_update => 1,
+    is_nullable   => 0
+};
+
 =head2 active
 
   data_type: 'boolean'
@@ -137,44 +211,30 @@ This ensures each record has a unique value and also allows for proper ordering.
 
 =cut
 
-__PACKAGE__->add_columns(
-  "navigation_id",
-  {
-    data_type         => "integer",
-    is_auto_increment => 1,
-    is_nullable       => 0,
-    sequence          => "navigation_navigation_id_seq",
-  },
-  "uri",
-  { data_type => "varchar", default_value => "", is_nullable => 0, size => 255 },
-  "type",
-  { data_type => "varchar", default_value => "", is_nullable => 0, size => 32 },
-  "scope",
-  { data_type => "varchar", default_value => "", is_nullable => 0, size => 32 },
-  "name",
-  { data_type => "varchar", default_value => "", is_nullable => 0, size => 255 },
-  "description",
-  { data_type => "varchar", default_value => "", is_nullable => 0, size => 1024 },
-  "alias",
-  { data_type => "integer", default_value => 0, is_nullable => 0 },
-  "parent_id",
-  { data_type => "integer", is_nullable => 1 },
-  "priority",
-  { data_type => "integer", default_value => 0, is_nullable => 0 },
-  "product_count",
-  { data_type => "integer", default_value => 0, is_nullable => 0 },
-  "created",
-  { data_type => "datetime", set_on_create => 1, is_nullable => 0 },
-  "last_modified",
-  { data_type => "datetime", set_on_create => 1, set_on_update => 1, is_nullable => 0 },
-  "active",
-  { data_type => "boolean", default_value => 1, is_nullable => 0 },
-);
+column active =>
+  { data_type => "boolean", default_value => 1, is_nullable => 0 };
 
 =head1 METHODS
 
 Attribute methods are provided by the L<Interchange6::Schema::Base::Attribute> class.
 
+=head2 siblings_with_self
+
+Similar to the inherited L<siblings|DBIx::Class::Tree::AdjacencyList/siblings> method but also returns the object itself in the result set/list.
+
+=cut
+
+sub siblings_with_self {
+    my $self = shift;
+    my $rs = $self->result_source->resultset->search(
+        {
+            parent_id => $self->parent_id,
+        }
+    );
+    return $rs->all() if (wantarray());
+    return $rs;
+}
+
 =head1 INHERITED METHODS
 
 =head2 DBIx::Class::Tree::AdjacencyList
@@ -227,32 +287,8 @@ L<is_branch|DBIx::Class::Tree::AdjacencyList/is_branch>
 
 =back
 
-=head1 PRIMARY KEY
-
-=over 4
-
-=item * L</navigation_id>
-
-=back
-
 =cut
 
-__PACKAGE__->set_primary_key("navigation_id");
-
-=head1 UNIQUE CONSTRAINTS
-
-=head2 C<navigation_uri_key>
-
-=over 4
-
-=item * L</uri>
-
-=back
-
-=cut
-
-__PACKAGE__->add_unique_constraint("navigation_uri_key", ["uri"]);
-
 # define parent column
 
 __PACKAGE__->parent_column('parent_id');
@@ -267,12 +303,22 @@ Related object: L<Interchange6::Schema::Result::NavigationProduct>
 
 =cut
 
-__PACKAGE__->has_many(
-  "navigation_products",
-  "Interchange6::Schema::Result::NavigationProduct",
-  { "foreign.navigation_id" => "self.navigation_id" },
-  { cascade_copy => 0, cascade_delete => 0 },
-);
+has_many
+  navigation_products => "Interchange6::Schema::Result::NavigationProduct",
+  "navigation_id",
+  { cascade_copy => 0, cascade_delete => 0 };
+
+=head2 products
+
+Type: many_to_many
+
+Accessor to related product results ordered by priority and name.
+
+=cut
+
+many_to_many
+  products => "navigation_products",
+  "product", { order_by => [ 'product.priority', 'product.name' ] };
 
 =head2 navigation_attributes
 
@@ -282,11 +328,9 @@ Related object: L<Interchange6::Schema::Result::NavigationAttribute>
 
 =cut
 
-__PACKAGE__->has_many(
-  "navigation_attributes",
-  "Interchange6::Schema::Result::NavigationAttribute",
-  { "foreign.navigation_id" => "self.navigation_id" },
-  { cascade_copy => 0, cascade_delete => 0 },
-);
+has_many
+  navigation_attributes => "Interchange6::Schema::Result::NavigationAttribute",
+  "navigation_id",
+  { cascade_copy => 0, cascade_delete => 0 };
 
 1;
