@@ -1,4 +1,5 @@
 use utf8;
+
 package Interchange6::Schema::Result::Orderline;
 
 =head1 NAME
@@ -7,16 +8,7 @@ Interchange6::Schema::Result::Orderline
 
 =cut
 
-use strict;
-use warnings;
-
-use base 'DBIx::Class::Core';
-
-=head1 TABLE: C<orderlines>
-
-=cut
-
-__PACKAGE__->table("orderlines");
+use Interchange6::Schema::Candy;
 
 =head1 ACCESSORS
 
@@ -26,6 +18,16 @@ __PACKAGE__->table("orderlines");
   is_auto_increment: 1
   is_nullable: 0
   sequence: 'orderlines_orderlines_id_seq'
+  primary key
+
+=cut
+
+primary_column orderlines_id => {
+    data_type         => "integer",
+    is_auto_increment => 1,
+    is_nullable       => 0,
+    sequence          => "orderlines_orderlines_id_seq",
+};
 
 =head2 orders_id
 
@@ -33,12 +35,22 @@ __PACKAGE__->table("orderlines");
   is_foreign_key: 1
   is_nullable: 0
 
+=cut
+
+column orders_id =>
+  { data_type => "integer", is_foreign_key => 1, is_nullable => 0 };
+
 =head2 order_position
 
   data_type: 'integer'
   default_value: 0
   is_nullable: 0
 
+=cut
+
+column order_position =>
+  { data_type => "integer", default_value => 0, is_nullable => 0 };
+
 =head2 sku
 
   data_type: 'varchar'
@@ -46,6 +58,11 @@ __PACKAGE__->table("orderlines");
   is_nullable: 0
   size: 64
 
+=cut
+
+column sku =>
+  { data_type => "varchar", is_foreign_key => 1, is_nullable => 0, size => 64 };
+
 =head2 name
 
   data_type: 'varchar'
@@ -53,6 +70,15 @@ __PACKAGE__->table("orderlines");
   is_nullable: 0
   size: 255
 
+=cut
+
+column name => {
+    data_type     => "varchar",
+    default_value => "",
+    is_nullable   => 0,
+    size          => 255
+};
+
 =head2 short_description
 
   data_type: 'varchar'
@@ -60,11 +86,24 @@ __PACKAGE__->table("orderlines");
   is_nullable: 0
   size: 500
 
+=cut
+
+column short_description => {
+    data_type     => "varchar",
+    default_value => "",
+    is_nullable   => 0,
+    size          => 500
+};
+
 =head2 description
 
   data_type: 'text'
   is_nullable: 0
 
+=cut
+
+column description => { data_type => "text", is_nullable => 0 };
+
 =head2 weight
 
   data_type: 'numeric'
@@ -72,11 +111,24 @@ __PACKAGE__->table("orderlines");
   is_nullable: 0
   size: [10,3]
 
+=cut
+
+column weight => {
+    data_type     => "numeric",
+    default_value => "0.0",
+    is_nullable   => 0,
+    size          => [ 10, 3 ]
+};
+
 =head2 quantity
 
   data_type: 'integer'
   is_nullable: 1
 
+=cut
+
+column quantity => { data_type => "integer", is_nullable => 1 };
+
 =head2 price
 
   data_type: 'numeric'
@@ -84,6 +136,15 @@ __PACKAGE__->table("orderlines");
   is_nullable: 0
   size: [10,2]
 
+=cut
+
+column price => {
+    data_type     => "numeric",
+    default_value => "0.0",
+    is_nullable   => 0,
+    size          => [ 10, 2 ],
+};
+
 =head2 subtotal
 
   data_type: 'numeric'
@@ -91,6 +152,15 @@ __PACKAGE__->table("orderlines");
   is_nullable: 0
   size: [11,2]
 
+=cut
+
+column subtotal => {
+    data_type     => "numeric",
+    default_value => "0.0",
+    is_nullable   => 0,
+    size          => [ 11, 2 ],
+};
+
 =head2 shipping
 
   data_type: 'numeric'
@@ -98,6 +168,15 @@ __PACKAGE__->table("orderlines");
   is_nullable: 0
   size: [11,2]
 
+=cut
+
+column shipping => {
+    data_type     => "numeric",
+    default_value => "0.0",
+    is_nullable   => 0,
+    size          => [ 11, 2 ],
+};
+
 =head2 handling
 
   data_type: 'numeric'
@@ -105,6 +184,15 @@ __PACKAGE__->table("orderlines");
   is_nullable: 0
   size: [11,2]
 
+=cut
+
+column handling => {
+    data_type     => "numeric",
+    default_value => "0.0",
+    is_nullable   => 0,
+    size          => [ 11, 2 ],
+};
+
 =head2 salestax
 
   data_type: 'numeric'
@@ -112,6 +200,15 @@ __PACKAGE__->table("orderlines");
   is_nullable: 0
   size: [11,2]
 
+=cut
+
+column salestax => {
+    data_type     => "numeric",
+    default_value => "0.0",
+    is_nullable   => 0,
+    size          => [ 11, 2 ],
+};
+
 =head2 status
 
   data_type: 'varchar'
@@ -121,80 +218,8 @@ __PACKAGE__->table("orderlines");
 
 =cut
 
-__PACKAGE__->add_columns(
-  "orderlines_id",
-  {
-    data_type         => "integer",
-    is_auto_increment => 1,
-    is_nullable       => 0,
-    sequence          => "orderlines_orderlines_id_seq",
-  },
-  "orders_id",
-  { data_type => "integer", is_foreign_key => 1, is_nullable => 0 },
-  "order_position",
-  { data_type => "integer", default_value => 0, is_nullable => 0 },
-  "sku",
-  { data_type => "varchar", is_foreign_key => 1, is_nullable => 0, size => 64 },
-  "name",
-  { data_type => "varchar", default_value => "", is_nullable => 0, size => 255 },
-  "short_description",
-  { data_type => "varchar", default_value => "", is_nullable => 0, size => 500 },
-  "description",
-  { data_type => "text", is_nullable => 0 },
-  "weight",
-  { data_type => "numeric", default_value => "0.0", is_nullable => 0, size => [10,3] },
-  "quantity",
-  { data_type => "integer", is_nullable => 1 },
-  "price",
-  {
-    data_type => "numeric",
-    default_value => "0.0",
-    is_nullable => 0,
-    size => [10, 2],
-  },
-  "subtotal",
-  {
-    data_type => "numeric",
-    default_value => "0.0",
-    is_nullable => 0,
-    size => [11, 2],
-  },
-  "shipping",
-  {
-    data_type => "numeric",
-    default_value => "0.0",
-    is_nullable => 0,
-    size => [11, 2],
-  },
-  "handling",
-  {
-    data_type => "numeric",
-    default_value => "0.0",
-    is_nullable => 0,
-    size => [11, 2],
-  },
-  "salestax",
-  {
-    data_type => "numeric",
-    default_value => "0.0",
-    is_nullable => 0,
-    size => [11, 2],
-  },
-  "status",
-  { data_type => "varchar", default_value => "", is_nullable => 0, size => 24 },
-);
-
-=head1 PRIMARY KEY
-
-=over 4
-
-=item * L</orderlines_id>
-
-=back
-
-=cut
-
-__PACKAGE__->set_primary_key("orderlines_id");
+column status =>
+  { data_type => "varchar", default_value => "", is_nullable => 0, size => 24 };
 
 =head1 RELATIONS
 
@@ -206,12 +231,10 @@ Related object: L<Interchange6::Schema::Result::Order>
 
 =cut
 
-__PACKAGE__->belongs_to(
-  "order",
-  "Interchange6::Schema::Result::Order",
-  { orders_id => "orders_id" },
-  { is_deferrable => 1, on_delete => "CASCADE", on_update => "CASCADE" },
-);
+belongs_to
+  order => "Interchange6::Schema::Result::Order",
+  "orders_id",
+  { is_deferrable => 1, on_delete => "CASCADE", on_update => "CASCADE" };
 
 =head2 orderlines_shipping
 
@@ -221,12 +244,10 @@ Related object: L<Interchange6::Schema::Result::OrderlinesShipping>
 
 =cut
 
-__PACKAGE__->has_many(
-  "orderlines_shipping",
-  "Interchange6::Schema::Result::OrderlinesShipping",
-  { "foreign.orderlines_id" => "self.orderlines_id" },
-  { cascade_copy => 0, cascade_delete => 0 },
-);
+has_many
+  orderlines_shipping => "Interchange6::Schema::Result::OrderlinesShipping",
+  "orderlines_id",
+  { cascade_copy => 0, cascade_delete => 0 };
 
 =head2 product
 
@@ -236,12 +257,10 @@ Related object: L<Interchange6::Schema::Result::Product>
 
 =cut
 
-__PACKAGE__->belongs_to(
-  "product",
-  "Interchange6::Schema::Result::Product",
-  { sku => "sku" },
-  { is_deferrable => 1, on_delete => "CASCADE", on_update => "CASCADE" },
-);
+belongs_to
+  product => "Interchange6::Schema::Result::Product",
+  "sku",
+  { is_deferrable => 1, on_delete => "CASCADE", on_update => "CASCADE" };
 
 =head2 addresses
 
@@ -251,6 +270,6 @@ Composing rels: L</orderlines_shipping> -> address
 
 =cut
 
-__PACKAGE__->many_to_many("addresses", "orderlines_shipping", "address");
+many_to_many addresses => "orderlines_shipping", "address";
 
 1;
