@@ -1,6 +1,6 @@
 package Test::Shipment;
 
-use Test::Most;
+use Test::Exception;
 use Test::Roo::Role;
 
 use DateTime;
@@ -13,7 +13,7 @@ test 'shipment tests' => sub {
 
     my ( $rset, %countries, %states, %zones, $data, $result );
 
-    my $schema = $self->schema;
+    my $schema = $self->ic6s_schema;
 
     # grab a few things from fixtures
 
@@ -89,9 +89,8 @@ test 'shipment tests' => sub {
     my $shipment_rate = $schema->resultset("ShipmentRate")
       ->find( { shipment_methods_id => $shipment_method->id } );
 
-    # stupid SQLite fp error due to price being float instead of numeric
-    # causes occasional failures so just rond price :-(
-    cmp_ok( sprintf("%.2f", $shipment_rate->price), '==', 9.95,
+    # ugly use of sprintf as SQLite uses float for numeric which can break test
+    cmp_ok( sprintf("%.02f", $shipment_rate->price), '==', 9.95,
         "Testing flat rate shipping price for UPS Ground lower 48 states." );
 
     my ( $product, $order );
@@ -132,7 +131,7 @@ test 'shipment tests' => sub {
         "Create order IC60001"
     );
 
-    my $orderline = $order->find_related( 'orderlines', '1' );
+    my $orderline = $order->orderlines->first;
 
     cmp_ok( $orderline->sku, 'eq', $product->sku,
         "Testing Orderline record creation." );
